Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(180)

Unified Diff: webrtc/call/rtp_demuxer.h

Issue 2958283002: nit: Rename RtpDemuxer::sink_ to RtpDemuxer::ssrc_sinks_ (Closed)
Patch Set: Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | webrtc/call/rtp_demuxer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/call/rtp_demuxer.h
diff --git a/webrtc/call/rtp_demuxer.h b/webrtc/call/rtp_demuxer.h
index 9ec93787dea7ab9f533483319eb2596973983006..5060a80a70806afe46213592f62d0f05c534bf7e 100644
--- a/webrtc/call/rtp_demuxer.h
+++ b/webrtc/call/rtp_demuxer.h
@@ -71,12 +71,12 @@ class RtpDemuxer {
// This records the association SSRCs to sinks. Other associations, such
// as by RSID, also end up here once the RSID, etc., is resolved to an SSRC.
- std::multimap<uint32_t, RtpPacketSinkInterface*> sinks_;
+ std::multimap<uint32_t, RtpPacketSinkInterface*> ssrc_sinks_;
danilchap 2017/06/28 14:05:39 while just 'sinks' is not properly differentiated
// A sink may be associated with an RSID - RTP Stream ID. This tag has a
// one-to-one association with an SSRC, but that SSRC is not yet known.
// When it becomes known, the association of the sink to the RSID is deleted
// from this container, and moved into |sinks_|.
std::multimap<std::string, RtpPacketSinkInterface*> rsid_sinks_;
// Iterating over |rsid_sinks_| for each incoming and performing multiple
« no previous file with comments | « no previous file | webrtc/call/rtp_demuxer.cc » ('j') | no next file with comments »
@@ -71,12 +71,12 @@ class RtpDemuxer {
// one-to-one association with an SSRC, but that SSRC is not yet known.
// When it becomes known, the association of the sink to the RSID is deleted
- // from this container, and moved into |sinks_|.
+ // from this container, and moved into |ssrc_sinks_|.
std::multimap<std::string, RtpPacketSinkInterface*> rsid_sinks_;
// Iterating over |rsid_sinks_| for each incoming and performing multiple

Powered by Google App Engine
This is Rietveld 408576698